@@ -9,7 +9,7 @@ from sphinx.util.i18n import format_date
 from sphinx.util.logging import getLogger
 
 
-__version__ = '0.2.1'
+__version__ = '0.2.3'
 
 
 logger = getLogger(__name__)
@@ -23,7 +23,7 @@ class TooShallow(Exception):
     """The file was last updated in the initial commit of a shallow clone."""
 
 
-def get_datetime(path):
+def get_datetime(path, tz):
     """Obtain the "author time" for *path* from Git."""
     path = Path(path)
 
@@ -45,7 +45,8 @@ def get_datetime(path):
         result = run_command(['git', 'rev-parse', '--is-shallow-repository'])
         if result.rstrip('\n') == 'true':
             raise TooShallow(path)
-    return datetime.fromtimestamp(int(timestamp), timezone.utc).astimezone()
+    utc_time = datetime.fromtimestamp(int(timestamp), timezone.utc)
+    return utc_time.astimezone(tz)
 
 
 def _html_page_context(app, pagename, templatename, context, doctree):
@@ -53,13 +54,15 @@ def _html_page_context(app, pagename, templatename, context, doctree):
     lufmt = app.config.html_last_updated_fmt
     if lufmt is None or 'sourcename' not in context:
         return
-    if 'singlehtml' in app.builder.name:
+    if 'page_source_suffix' not in context:
+        # This happens in 'singlehtml' builders
         assert context['sourcename'] == ''
         return
     sourcefile = Path(app.confdir, pagename + context['page_source_suffix'])
     dates = []
     try:
-        dates.append(get_datetime(sourcefile))
+        dates.append(get_datetime(
+            sourcefile, app.config.git_last_updated_timezone))
     except subprocess.CalledProcessError as e:
         raise sphinx.errors.ExtensionError(e.stderr, e)
     except FileNotFoundError as e:
@@ -77,7 +80,7 @@ def _html_page_context(app, pagename, templatename, context, doctree):
     for dep in app.env.dependencies[pagename]:
         path = Path(app.confdir, dep)
         try:
-            date = get_datetime(path)
+            date = get_datetime(path, app.config.git_last_updated_timezone)
         except Exception:
             continue
         else:
@@ -90,15 +93,26 @@ def _html_page_context(app, pagename, templatename, context, doctree):
                 type='git', subtype='too_shallow')
         return
 
+    date = max(dates)
+
     context['last_updated'] = format_date(
         lufmt or _('%b %d, %Y'),
-        date=max(dates),
+        date=date,
         language=app.config.language)
 
+    if app.config.git_last_updated_metatags:
+        context['metatags'] += """
+    <meta property="article:modified_time" content="{}" />""".format(
+            date.isoformat())
+
 
 def _config_inited(app, config):
     if config.html_last_updated_fmt is None:
         config.html_last_updated_fmt = ''
+    if isinstance(config.git_last_updated_timezone, str):
+        from babel.dates import get_timezone
+        config.git_last_updated_timezone = get_timezone(
+            config.git_last_updated_timezone)
 
 
 def setup(app):
@@ -110,6 +124,10 @@ def setup(app):
         'git_untracked_check_dependencies', True, rebuild='html')
     app.add_config_value(
         'git_untracked_show_sourcelink', False, rebuild='html')
+    app.add_config_value(
+        'git_last_updated_timezone', None, rebuild='html')
+    app.add_config_value(
+        'git_last_updated_metatags', True, rebuild='html')
     return {
         'version': __version__,
         'parallel_read_safe': True,
